@@ -200,15 +200,25 @@ Ext.m3.AdvancedComboBox = Ext.extend(Ext.m3.ComboBox, {
             var triggerIndex = 'Trigger' + (index + 1);
             t.hide = function () {
                 var w = triggerField.wrap.getWidth();
+                if (w === 0) {
+                    w = triggerField.bufferSize;
+                    triggerField.wrap.setWidth(w);
+                }
+
                 this.dom.style.display = 'none';
-                triggerField.el.setWidth(w - triggerField.trigger.getWidth());
                 triggerField['hidden' + triggerIndex] = true;
+                triggerField.el.setWidth(w - triggerField.getTriggerWidth());
             };
             t.show = function () {
                 var w = triggerField.wrap.getWidth();
+                if (w === 0) {
+                    w = triggerField.bufferSize;
+                    triggerField.wrap.setWidth(w);
+                }
+
                 this.dom.style.display = '';
-                triggerField.el.setWidth(w - triggerField.trigger.getWidth());
                 triggerField['hidden' + triggerIndex] = false;
+                triggerField.el.setWidth(w - triggerField.getTriggerWidth());
             };
 
             if (this.allTriggers[index].hide) {
@@ -381,6 +391,46 @@ Ext.m3.AdvancedComboBox = Ext.extend(Ext.m3.ComboBox, {
             this.hiddenTrigger1 = true;
         }
     },
+    /**
+     * Показывает кнопку выбора из справочника
+     */
+    showDictSelectBtn: function () {
+        if (!this.hideTriggerDictSelect && this.rendered && !this.readOnly && !this.disabled) {
+            this.getTrigger(2).show();
+        } else {
+            this.hiddenTrigger3 = false || this.hideTriggerDictSelect || this.readOnly || this.disabled;
+        }
+    },
+    /**
+     * Скрывает кнопку выбора из справочника
+     */
+    hideDictSelectBtn: function () {
+        if (this.rendered) {
+            this.getTrigger(2).hide();
+        } else {
+            this.hiddenTrigger3 = true;
+        }
+    },
+    /**
+     * Показывает кнопку выпадающего списка
+     */
+    showDropDownBtn: function () {
+        if (!this.hideTriggerDropDown && this.rendered && !this.readOnly && !this.disabled) {
+            this.getTrigger(1).show();
+        } else {
+            this.hiddenTrigger2 = false || this.hideTriggerDropDown || this.readOnly || this.disabled;
+        }
+    },
+    /**
+     * Скрывает кнопку выпадающего списка
+     */
+    hideDropDownBtn: function () {
+        if (this.rendered) {
+            this.getTrigger(1).hide();
+        } else {
+            this.hiddenTrigger2 = true;
+        }
+    },
     /**
      * Показывает кнопку открытия карточки элемента
      */
@@ -590,17 +640,20 @@ Ext.m3.AdvancedComboBox = Ext.extend(Ext.m3.ComboBox, {
                 this.showClearBtn();
                 this.showEditBtn();
             }
-            if (!this.hideTriggerDictSelect) {
-                this.getTrigger(2).show();
-            }
-            if (!this.hideTriggerDropDown) {
-                this.getTrigger(1).show();
-            }
+            this.showDictSelectBtn();
+            this.showDropDownBtn();
         } else {
-            this.hideClearBtn();
-            this.hideEditBtn();
-            this.getTrigger(2).hide();
-            this.getTrigger(1).hide();
+            if (this.triggers){ // this.triggers появляется только после рендера
+                this.hideClearBtn();
+                this.hideEditBtn();
+                this.hideDictSelectBtn();
+                this.hideDropDownBtn();
+            } else { // иначе достаточно просто пометить соответствующие поля
+                this.hiddenTrigger1 = true; // для правильного расчета
+                this.hiddenTrigger2 = true; // ширины триггеров
+                this.hiddenTrigger3 = true;
+                this.hiddenTrigger4 = true;
+            }
         }
     },
 
@@ -621,15 +674,18 @@ Ext.m3.AdvancedComboBox = Ext.extend(Ext.m3.ComboBox, {
      */
     setReadOnly: function (readOnly) {
         var width = this.getWidth();
+        if (width === 0) {
+            width = this.bufferSize;
+        }
+
         this.disableTriggers(readOnly);
+        this.showTriggers(!readOnly); // скрытие/показ триггеров
+
         Ext.m3.AdvancedComboBox.superclass.setReadOnly.call(this, readOnly);
         if (readOnly) {
             this.el.setWidth(width);
             if (this.wrap) this.wrap.setWidth(width);
         } else {
-
-            this.showTriggers(!readOnly);
-
             this.onResize(width);
         }
     }
