@@ -66,11 +66,11 @@ class BaseExtContainer(ExtUIComponent):
         :param name: имя экземпляра
         :type name: str
         """
-        for item in self.items:
+        for item in self._items:
             if hasattr(item, 'name') and name == getattr(item, 'name'):
                 return item
 
-            if hasattr(item, 'items'):
+            if hasattr(item, 'find_by_name'):
                 res = item.find_by_name(name)
                 if res:
                     return res
