@@ -1,8 +1,6 @@
 #coding:utf-8
-'''
+"""
 Дополнительный функционал
-'''
+"""
 from store import ExtDataStore, ExtJsonStore
-from connection import ExtConnection
 from label import ExtLabel
-
